History
=======

0.1.1 (2015-05-08)
------------------

* Fixes test data of pretty_print, linkdraw.

0.1.0 (2015-05-07)
------------------

* Supports generating linkdraw data.
* Supports pip 6.1.1 over.
* Supports wheel format for distribution.
* Adds unit tests.

0.0.1 (2015-04-29)
------------------

* First release
